*----------------------------------------------------------
* initialize_parameters.do
*----------------------------------------------------------
*
* Computes reduced-form estimates of four equations 
* (price,sale,down,default) with simplified error 
* correlation structure. These estimates serve as the 
* starting values for the full maximum likelihood routine.
*
*----------------------------------------------------------
* Load data into Stata
*----------------------------------------------------------
clear
clear matrix
set mem 800m
set more off
insheet using full_data.csv, clear

*----------------------------------------------------------
* Define key variables
*----------------------------------------------------------

*sale indicator
ren v1 I

*vehicle price
ren v2 pK

*minimum down
ren v3 dK

*list price
ren v4 lK

*total down
ren v5 tK

*amount financed
ren v6 afK

*fraction of payments made
ren v7 fracpaid

*fraction of term observed
ren v8 fracobs

*----------------------------------------------------------
* Run reduced-form regressions
*----------------------------------------------------------
*set explanatory variables
global X = "v10-v54"

*price and sale equations
reg pK $X lK
probit I $X dK
constraint 1 [pK]dK=0
ivprobit I (pK=lK) $X dK, first constraints(1)

*down equation
gen minusless = -(tK<=dK)
cnreg tK $X pK if I, cen(minusless)
predict xb, xb
predict e, e(.,dK)
gen downresid=tK-xb if tK>dK & I
replace downresid=e-xb if tK<=dK & I

*default equation
gen centemp = (fracpaid>=fracobs-0.05)
replace centemp = -1 if fracpaid<=0.0125
gen fractemp = fracpaid
replace fractemp = 0.0125 if fracpaid<0.0125
gen logfrac = log(fractemp)
cnreg logfrac $X afK downresid if I, cen(centemp)

*----------------------------------------------------------
* End of program
*----------------------------------------------------------